summaryrefslogtreecommitdiffstats
path: root/korganizer/actionmanager.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /korganizer/actionmanager.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'korganizer/actionmanager.cpp')
-rw-r--r--korganizer/actionmanager.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/korganizer/actionmanager.cpp b/korganizer/actionmanager.cpp
index 8b938986..09b5c6f4 100644
--- a/korganizer/actionmanager.cpp
+++ b/korganizer/actionmanager.cpp
@@ -21,8 +21,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include "actionmanager.h"
@@ -81,9 +81,9 @@
KOWindowList *ActionManager::mWindowList = 0;
ActionManager::ActionManager( KXMLGUIClient *client, CalendarView *widget,
- TQObject *parent, KOrg::MainWindow *mainWindow,
+ TQObject *tqparent, KOrg::MainWindow *mainWindow,
bool isPart )
- : TQObject( parent ), KCalendarIface(), mRecent( 0 ),
+ : TQObject( tqparent ), KCalendarIface(), mRecent( 0 ),
mResourceButtonsAction( 0 ), mResourceViewShowAction( 0 ), mCalendar( 0 ),
mCalendarResources( 0 ), mResourceView( 0 ), mIsClosing( false )
{
@@ -130,7 +130,7 @@ void ActionManager::init()
TQTimer::singleShot( 0, this, TQT_SLOT( showTipOnStart() ) );
}
// Note: We need this ActionManager to be fully constructed, and
// parent() to have a valid reference to it before the following
// addWindow is called.
mWindowList->addWindow( mMainWindow );
@@ -313,10 +313,10 @@ void ActionManager::initActions()
mCalendarView, TQT_SLOT( appointment_delete() ),
mACollection, "edit_delete" );
if ( mIsPart ) {
- KStdAction::find( mCalendarView->dialogManager(), TQT_SLOT( showSearchDialog() ),
- mACollection, "korganizer_find" );
+ KStdAction::tqfind( mCalendarView->dialogManager(), TQT_SLOT( showSearchDialog() ),
+ mACollection, "korganizer_tqfind" );
} else {
- KStdAction::find( mCalendarView->dialogManager(), TQT_SLOT( showSearchDialog() ),
+ KStdAction::tqfind( mCalendarView->dialogManager(), TQT_SLOT( showSearchDialog() ),
mACollection );
}
pasteAction->setEnabled( false );
@@ -402,7 +402,7 @@ void ActionManager::initActions()
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ZOOM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// TODO: try to find / create better icons for the following 4 actions
new KAction( i18n( "Zoom In Horizontally" ), "viewmag+", 0,
mCalendarView->viewManager(), TQT_SLOT( zoomInHorizontally() ),
mACollection, "zoom_in_horizontally" );
@@ -522,7 +522,7 @@ void ActionManager::initActions()
connect( mCalendarView, TQT_SIGNAL(organizerEventsSelected(bool)),
mSendCancel, TQT_SLOT(setEnabled(bool)) );
- mSendStatusUpdate = new KAction( i18n( "Send Status &Update" ),
+ mSendStatusUpdate = new KAction( i18n( "Send tqStatus &Update" ),
"mail_reply", 0,
mCalendarView,TQT_SLOT(schedule_reply()),
mACollection, "schedule_reply" );
@@ -1162,7 +1162,7 @@ bool ActionManager::saveModifiedURL()
int result = KMessageBox::warningYesNoCancel(
dialogParent(),
i18n("The calendar has been modified.\nDo you want to save it?"),
- TQString::null,
+ TQString(),
KStdGuiItem::save(), KStdGuiItem::discard() );
switch( result ) {
case KMessageBox::Yes:
@@ -1305,7 +1305,7 @@ void ActionManager::configureDateTime()
void ActionManager::showTip()
{
- KTipDialog::showTip( dialogParent(),TQString::null,true );
+ KTipDialog::showTip( dialogParent(),TQString(),true );
}
void ActionManager::showTipOnStart()
@@ -1534,7 +1534,7 @@ void ActionManager::setTitle()
mMainWindow->setTitle();
}
-KCalendarIface::ResourceRequestReply ActionManager::resourceRequest( const TQValueList<QPair<TQDateTime, TQDateTime> >&,
+KCalendarIface::ResourceRequestReply ActionManager::resourceRequest( const TQValueList<TQPair<TQDateTime, TQDateTime> >&,
const TQCString& resource,
const TQString& vCalIn )
{
@@ -1544,9 +1544,9 @@ KCalendarIface::ResourceRequestReply ActionManager::resourceRequest( const TQVal
return reply;
}
-QPair<ResourceCalendar *, TQString> ActionManager::viewSubResourceCalendar()
+TQPair<ResourceCalendar *, TQString> ActionManager::viewSubResourceCalendar()
{
- QPair<ResourceCalendar *, TQString> p( 0, TQString() );
+ TQPair<ResourceCalendar *, TQString> p( 0, TQString() );
// return now if we are running as a part and we aren't the currently active part
if ( mIsPart && !mMainWindow->isCurrentlyActivePart() ) {
@@ -1634,7 +1634,7 @@ bool ActionManager::isWritable( ResourceCalendar *res, const TQString &subRes,
void ActionManager::openEventEditor( const TQString& text )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
if ( isWritable( p.first, p.second, "event" ) ) {
mCalendarView->newEvent( p.first, p.second, text );
}
@@ -1644,7 +1644,7 @@ void ActionManager::openEventEditor( const TQString& summary,
const TQString& description,
const TQString& attachment )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
mCalendarView->newEvent( p.first, p.second, summary, description, attachment );
}
@@ -1708,11 +1708,11 @@ void ActionManager::openEventEditor( const TQString & summary,
return;
// due to kmime shortcomings in KDE3, we need to assemble the result manually
int begin = 0;
- int end = head.find( '\n' );
+ int end = head.tqfind( '\n' );
bool skipFolded = false;
while ( end >= 0 && end > begin ) {
- if ( head.find( "Content-Type:", begin, false ) != begin &&
- head.find( "Content-Transfer-Encoding:", begin, false ) != begin &&
+ if ( head.tqfind( "Content-Type:", begin, false ) != begin &&
+ head.tqfind( "Content-Transfer-Encoding:", begin, false ) != begin &&
!(skipFolded && (head[begin] == ' ' || head[end] == '\t')) ) {
TQCString line = head.mid( begin, end - begin );
tf.file()->writeBlock( line.data(), line.length() );
@@ -1723,7 +1723,7 @@ void ActionManager::openEventEditor( const TQString & summary,
}
begin = end + 1;
- end = head.find( '\n', begin );
+ end = head.tqfind( '\n', begin );
if ( end < 0 && begin < (int)head.length() )
end = head.length() - 1;
}
@@ -1748,14 +1748,14 @@ void ActionManager::openEventEditor( const TQString & summary,
return;
}
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
mCalendarView->newEvent( p.first, p.second, summary, description, attData,
attendees, attachmentMimetype, action != KOPrefs::Link );
}
void ActionManager::openTodoEditor( const TQString& text )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
if ( isWritable( p.first, p.second, "todo" ) ) {
mCalendarView->newTodo( p.first, p.second, text );
}
@@ -1765,7 +1765,7 @@ void ActionManager::openTodoEditor( const TQString& summary,
const TQString& description,
const TQString& attachment )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
mCalendarView->newTodo( p.first, p.second, summary, description, attachment );
}
@@ -1774,7 +1774,7 @@ void ActionManager::openTodoEditor( const TQString& summary,
const TQString& attachment,
const TQStringList& attendees )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
mCalendarView->newTodo( p.first, p.second, summary, description, attachment, attendees );
}
@@ -1814,7 +1814,7 @@ void ActionManager::openTodoEditor(const TQString & summary,
return;
}
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
mCalendarView->newTodo( p.first, p.second,
summary, description,
attData, attendees,
@@ -1825,19 +1825,19 @@ void ActionManager::openTodoEditor(const TQString & summary,
void ActionManager::openJournalEditor( const TQDate& date )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
mCalendarView->newJournal( p.first, p.second, date );
}
void ActionManager::openJournalEditor( const TQString& text, const TQDate& date )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
mCalendarView->newJournal( p.first, p.second, text, date );
}
void ActionManager::openJournalEditor( const TQString& text )
{
- QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
if ( isWritable( p.first, p.second, "journal" ) ) {
mCalendarView->newJournal( p.first, p.second, text );
}
@@ -1848,7 +1848,7 @@ void ActionManager::openJournalEditor( const TQString& text )
// const TQString& description,
// const TQString& attachment )
// {
-// QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+// TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
// mCalendarView->newJournal( p.first, p.second, summary, description, attachment );
// }
@@ -1916,12 +1916,12 @@ bool ActionManager::queryClose()
if ( mCalendar && mCalendar->isModified() ) {
int res = KMessageBox::questionYesNoCancel( dialogParent(),
- i18n("The calendar tqcontains unsaved changes. Do you want to save them before exiting?"), TQString::null, KStdGuiItem::save(), KStdGuiItem::discard() );
+ i18n("The calendar contains unsaved changes. Do you want to save them before exiting?"), TQString(), KStdGuiItem::save(), KStdGuiItem::discard() );
// Exit on yes and no, don't exit on cancel. If saving fails, ask for exiting.
if ( res == KMessageBox::Yes ) {
close = saveModifiedURL();
if ( !close ) {
- int res1 = KMessageBox::questionYesNo( dialogParent(), i18n("Unable to save the calendar. Do you still want to close this window?"), TQString::null, KStdGuiItem::close(), KStdGuiItem::cancel() );
+ int res1 = KMessageBox::questionYesNo( dialogParent(), i18n("Unable to save the calendar. Do you still want to close this window?"), TQString(), KStdGuiItem::close(), KStdGuiItem::cancel() );
close = ( res1 == KMessageBox::Yes );
}
} else {
@@ -130,7 +130,7 @@ void ActionManager::init()
}
// Note: We need this ActionManager to be fully constructed, and
- // parent() to have a valid reference to it before the following
+ // tqparent() to have a valid reference to it before the following
// addWindow is called.
mWindowList->addWindow( mMainWindow );
@@ -402,7 +402,7 @@ void ActionManager::initActions()
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ZOOM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- // TODO: try to find / create better icons for the following 4 actions
+ // TODO: try to tqfind / create better icons for the following 4 actions
new KAction( i18n( "Zoom In Horizontally" ), "viewmag+", 0,
mCalendarView->viewManager(), TQT_SLOT( zoomInHorizontally() ),